summaryrefslogtreecommitdiffstats
path: root/content/public/browser/web_contents_delegate.h
diff options
context:
space:
mode:
authorbokan <bokan@chromium.org>2015-02-03 15:23:39 -0800
committerCommit bot <commit-bot@chromium.org>2015-02-03 23:24:29 +0000
commit107a47faa8f7e9c38cd0e7aeac74751b103df215 (patch)
tree2d902d3f5e7d9632c1c007b4ae11175f7c56f14e /content/public/browser/web_contents_delegate.h
parent8da6aa6d5f5d4000fa733df814e83ff57da56dca (diff)
downloadchromium_src-107a47faa8f7e9c38cd0e7aeac74751b103df215.zip
chromium_src-107a47faa8f7e9c38cd0e7aeac74751b103df215.tar.gz
chromium_src-107a47faa8f7e9c38cd0e7aeac74751b103df215.tar.bz2
Rename initial_pos to initial_rect in ShowWidget and ShowView IPCs.
These IPCs hold this param as a gfx::Rect and the RenderWidget and RenderView set the size. On the receiving end, the size is sometimes used so initial_pos was a misnomer. This is a mechanical rename, there should be no functional difference. TBR= BUG= Review URL: https://codereview.chromium.org/889403004 Cr-Commit-Position: refs/heads/master@{#314430}
Diffstat (limited to 'content/public/browser/web_contents_delegate.h')
-rw-r--r--content/public/browser/web_contents_delegate.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/content/public/browser/web_contents_delegate.h b/content/public/browser/web_contents_delegate.h
index 13d1c1d..33450ac 100644
--- a/content/public/browser/web_contents_delegate.h
+++ b/content/public/browser/web_contents_delegate.h
@@ -94,14 +94,14 @@ class CONTENT_EXPORT WebContentsDelegate {
// Creates a new tab with the already-created WebContents 'new_contents'.
// The window for the added contents should be reparented correctly when this
// method returns. If |disposition| is NEW_POPUP, |initial_pos| should hold
// the initial position. If |was_blocked| is non-nullptr, then |*was_blocked|
// will be set to true if the popup gets blocked, and left unchanged
// otherwise.
virtual void AddNewContents(WebContents* source,
WebContents* new_contents,
WindowOpenDisposition disposition,
- const gfx::Rect& initial_pos,
+ const gfx::Rect& initial_rect,
bool user_gesture,
bool* was_blocked) {}
@@ -94,14 +94,14 @@ class CONTENT_EXPORT WebContentsDelegate {
// Creates a new tab with the already-created WebContents 'new_contents'.
// The window for the added contents should be reparented correctly when this
- // method returns. If |disposition| is NEW_POPUP, |initial_pos| should hold
- // the initial position. If |was_blocked| is non-nullptr, then |*was_blocked|
- // will be set to true if the popup gets blocked, and left unchanged
- // otherwise.
+ // method returns. If |disposition| is NEW_POPUP, |initial_rect| should hold
+ // the initial position and size. If |was_blocked| is non-nullptr, then
+ // |*was_blocked| will be set to true if the popup gets blocked, and left
+ // unchanged otherwise.
virtual void AddNewContents(WebContents* source,
WebContents* new_contents,